%% ----------------- Information --------------
% Implementation of Local Frequency Descriptor (LFD) Magnitude
% Please cite the following paper if you use the code.
% Reference: R. Maani, S. Kalra, and Y.H. Yang, "Noise robust rotation invariant features for texture classification", Pattern Recognition 46(8), pp. 21032116, 2013.
% 
% Copyright (C) 2013 Rouzbeh Maani  
% All rights reserved.
% 
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% at your option any later version.
% See the GNU General Public License for more details.


%% -------------- External Codes ---------------
% The matlab files used from the implementation of clpb (http://www.comp.polyu.edu.hk/~cslzhang/code/CLBP.rar)
% ClassifyOnNN, ReadOutexTxt
% The matlab files used from the Oxford texture classification filter bank 
% DGFilters


%% ---------------------------------
%  This program performs classification on the Outex TC 10 (http://www.outex.oulu.fi/)

%% ---------------------------------

function testTC10()
%% ------------------------- Reading Data -----------------------------
tic
rootpic = 'D:\Academic\Research\Data\Texture\Outex\Outex_TC_00010\';
radii1 = [10,18:3:45];
R1 = 3;
N1 = 24;
ChNo1 = 12;
% training and test samples
trainTxt = sprintf('%s000\\train.txt', rootpic);
testTxt = sprintf('%s000\\test.txt', rootpic);
[trainIDs, trainClassIDs] = ReadOutexTxt(trainTxt);
[testIDs, testClassIDs] = ReadOutexTxt(testTxt);
alldata = [trainIDs,testIDs];
%% ------------------------- Computing Features -----------------------------
tic
for i=1:length(alldata)%length(trainIDs)
    textureID = alldata(i);
    filename = sprintf('%s\\images\\%06d.ras', rootpic, textureID-1);
    Gray = imread(filename);
    I = im2double(Gray);
    I = (I-mean(I(:)))/std(I(:)); % image normalization
    H3(i,:) = lfd_mag(I,R1,N1,ChNo1,radii1);
    if(mod(i,180)==0)
        g=toc;
        fprintf('%%%2.2f time:%2.2f\n',i/length(alldata)*100,g);
        tic
    end
end
save(['tc10_ch' num2str(ChNo1) '_d' num2str(length(radii1)-1) '_r' num2str(R1) '_n' num2str(N1)],'H3');
H = load(['tc10_ch' num2str(ChNo1) '_d' num2str(length(radii1)-1) '_r' num2str(R1) '_n' num2str(N1)]);

for chan=1:ChNo1
H3 = H.H3(:,[1:(length(radii1)-1)*chan,ChNo1*(length(radii1)-1)+1:ChNo1*(length(radii1)-1)+(length(radii1)-1)*chan,ChNo1*(length(radii1)-1)*2+1:ChNo1*(length(radii1)-1)*2+3*chan]);    
fprintf('------------ch=%d, %d-------------\n',chan,size(H3,2));
trains = H3(1:length(trainIDs),:);
tests = H3(length(trainIDs)+1:end,:);
trainNum = size(trains,1);
testNum = size(tests,1);
DM = zeros(testNum,trainNum);
for i=1:testNum;
    test = tests(i,:);      
    DM(i,:) = distL1(trains,test)';
end
CP=ClassifyOnNN(DM,trainClassIDs,testClassIDs);
fprintf('%2.2f\n',CP);

end